class LayoutYullioGenerator < Rails::Generator::NamedBase
  MOLLIO = 'mollio_version1.1'
  MOLLIO_YUI = 'mollio-yui'
  YUI = 'yui_0.12.1'
  
  def initialize(*runtime_args)
    super(*runtime_args)
    
    @controller = singular_name
    @partial = args.shift || "secondary"
  end
  
  def banner
    "Usage: #{$0} layout_yullio ControllerName secondary_partial"
  end
   
  private
  def fjoin(array, fn=nil)
    x = array.clone
    File.join(fn ? x << fn : x)
  end
   
  def manifest
    record do |m|
      # directories to put things in
      psm = ['public', 'stylesheets', 'mollio-yui']
      psmi = ['public', 'stylesheets', 'mollio-yui', 'images']
      psyr = ['public', 'stylesheets', 'yui', 'reset-fonts-grids']
      pjm = ['public', 'javascripts', 'mollio']
      avl = ['app', 'views', 'layouts']
      avc = ['app', 'views', @controller]
      vpy = ['vendor', 'plugins', 'yullio']
      
      # source directories
      css = [MOLLIO_YUI, 'css']
      js = [MOLLIO, 'js']
      img = [MOLLIO, 'css', 'images']
      yahoo = [YUI, 'build', 'reset-fonts-grids']
      plugin = ['plugins', 'yullio']
      
      m.directory fjoin(psm)
      m.directory fjoin(psmi)
      m.directory fjoin(psyr)
      m.directory fjoin(pjm)
      m.directory fjoin(avl)
      m.directory fjoin(avc)
      m.directory fjoin(vpy)

      m.file fjoin(css, 'mollio-yui.css'), fjoin(psm, 'mollio-yui.css')
      m.file fjoin(js, 'common.js'), fjoin(pjm, 'common.js')
      m.file fjoin(yahoo, 'reset-fonts-grids.css'), fjoin(psyr, 'reset-fonts-grids.css')
      m.file fjoin(plugin, 'init.rb'), fjoin(vpy, 'init.rb')
      
      imgfiles = %w(2nd_nav_bg.gif body_bg.gif content_wrap_bg.gif content_wrap_e_bg.gif featurebox2_bg.gif featurebox_bg.gif header_bg.gif sprites.gif td_bg.gif)
      imgfiles.each { |x| m.file fjoin(img, x), fjoin(psmi, x) }

      m.template 'layout.rhtml', fjoin(avl, "#{@controller}.rhtml"), :assigns => { :partial => @partial }
      m.template 'partial.rhtml', fjoin(avc, "_#{@partial}.rhtml"), :assigns => {:name => @partial }
    end
  end
end

